@@ -9,6 +9,7 @@ import pytz
 import six
 import sys
 
+from apscheduler.job import Job
 from apscheduler.util import (
     asint, asbool, astimezone, convert_to_datetime, datetime_to_utc_timestamp,
     utc_timestamp_to_datetime, timedelta_seconds, datetime_ceil, get_callable_name, obj_to_ref,
@@ -42,6 +43,10 @@ class DummyClass(object):
             pass
 
 
+class InheritedDummyClass(Job):
+    pass
+
+
 class TestAsint(object):
     @pytest.mark.parametrize('value', ['5s', 'shplse'], ids=['digit first', 'text'])
     def test_invalid_value(self, value):
@@ -107,9 +112,15 @@ class TestConvertToDatetime(object):
         (datetime(2009, 8, 1, 5, 6, 12), datetime(2009, 8, 1, 5, 6, 12)),
         ('2009-8-1', datetime(2009, 8, 1)),
         ('2009-8-1 5:16:12', datetime(2009, 8, 1, 5, 16, 12)),
+        ('2009-8-1T5:16:12Z', datetime(2009, 8, 1, 5, 16, 12, tzinfo=pytz.utc)),
+        ('2009-8-1T5:16:12+02:30',
+         pytz.FixedOffset(150).localize(datetime(2009, 8, 1, 5, 16, 12))),
+        ('2009-8-1T5:16:12-05:30',
+         pytz.FixedOffset(-330).localize(datetime(2009, 8, 1, 5, 16, 12))),
         (pytz.FixedOffset(-60).localize(datetime(2009, 8, 1)),
          pytz.FixedOffset(-60).localize(datetime(2009, 8, 1)))
-    ], ids=['None', 'date', 'datetime', 'date as text', 'datetime as text', 'existing tzinfo'])
+    ], ids=['None', 'date', 'datetime', 'date as text', 'datetime as text', 'utc', 'tzoffset',
+            'negtzoffset', 'existing tzinfo'])
     def test_date(self, timezone, input, expected):
         returned = convert_to_datetime(input, timezone, None)
         if expected is not None:
@@ -209,22 +220,23 @@ class TestObjToRef(object):
         assert str(exc.value) == 'Cannot create a reference to a nested function'
 
     @pytest.mark.parametrize('input,expected', [
-        pytest.mark.skipif(sys.version_info[:2] == (3, 2),
-                           reason="Unbound methods can't be resolved on Python 3.2")(
-            (DummyClass.meth, 'tests.test_util:DummyClass.meth')
-        ),
+        (DummyClass.meth, 'tests.test_util:DummyClass.meth'),
         (DummyClass.classmeth, 'tests.test_util:DummyClass.classmeth'),
-        pytest.mark.skipif(sys.version_info < (3, 3),
-                           reason="Requires __qualname__ (Python 3.3+)")(
-            (DummyClass.InnerDummyClass.innerclassmeth,
-             'tests.test_util:DummyClass.InnerDummyClass.innerclassmeth')
+        pytest.param(
+            DummyClass.InnerDummyClass.innerclassmeth,
+            'tests.test_util:DummyClass.InnerDummyClass.innerclassmeth',
+            marks=[pytest.mark.skipif(sys.version_info < (3, 3),
+                                      reason="Requires __qualname__ (Python 3.3+)")]
         ),
-        pytest.mark.skipif(sys.version_info < (3, 3),
-                           reason="Requires __qualname__ (Python 3.3+)")(
-            (DummyClass.staticmeth, 'tests.test_util:DummyClass.staticmeth')
+        pytest.param(
+            DummyClass.staticmeth,
+            'tests.test_util:DummyClass.staticmeth',
+            marks=[pytest.mark.skipif(sys.version_info < (3, 3),
+                                      reason="Requires __qualname__ (Python 3.3+)")]
         ),
         (timedelta, 'datetime:timedelta'),
-    ], ids=['unbound method', 'class method', 'inner class method', 'static method', 'timedelta'])
+    ], ids=['class method', 'inner class method', 'static method', 'inherited class method',
+            'timedelta'])
     def test_valid_refs(self, input, expected):
         assert obj_to_ref(input) == expected
 
